==> hibernate-search-backend-elasticsearch-6.0.0.Final-sources.jar: org/hibernate/search/backend/elasticsearch/logging/impl/ElasticsearchEventContextMessages_$bundle.java <==
package org.hibernate.search.backend.elasticsearch.logging.impl;

import java.util.Locale;
import java.io.Serializable;
import java.lang.String;

/**
 * Warning this class consists of generated code.
 */
public class ElasticsearchEventContextMessages_$bundle implements ElasticsearchEventContextMessages, Serializable {
    private static final long serialVersionUID = 1L;
    protected ElasticsearchEventContextMessages_$bundle() {}
    public static final ElasticsearchEventContextMessages_$bundle INSTANCE = new ElasticsearchEventContextMessages_$bundle();
    protected Object readResolve() {
        return INSTANCE;
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    protected String mappingAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String mappingAttribute(final String name) {
        return String.format(getLoggingLocale(), mappingAttribute$str(), name);
    }
    protected String analysisDefinitionParameter$str() {
        return "parameter '%1$s'";
    }
    @Override
    public final String analysisDefinitionParameter(final String name) {
        return String.format(getLoggingLocale(), analysisDefinitionParameter$str(), name);
    }
    protected String aliasDefinition$str() {
        return "alias '%1$s'";
    }
    @Override
    public final String aliasDefinition(final String name) {
        return String.format(getLoggingLocale(), aliasDefinition$str(), name);
    }
    protected String analysisDefinitionAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String analysisDefinitionAttribute(final String name) {
        return String.format(getLoggingLocale(), analysisDefinitionAttribute$str(), name);
    }
    protected String fieldTemplateAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String fieldTemplateAttribute(final String name) {
        return String.format(getLoggingLocale(), fieldTemplateAttribute$str(), name);
    }
}

==> hibernate-search-backend-elasticsearch-6.1.5.Final-sources.jar: org/hibernate/search/backend/elasticsearch/logging/impl/ElasticsearchEventContextMessages_$bundle.java <==
package org.hibernate.search.backend.elasticsearch.logging.impl;

import java.util.Locale;
import java.io.Serializable;
import java.lang.String;

/**
 * Warning this class consists of generated code.
 */
public class ElasticsearchEventContextMessages_$bundle implements ElasticsearchEventContextMessages, Serializable {
    private static final long serialVersionUID = 1L;
    protected ElasticsearchEventContextMessages_$bundle() {}
    public static final ElasticsearchEventContextMessages_$bundle INSTANCE = new ElasticsearchEventContextMessages_$bundle();
    protected Object readResolve() {
        return INSTANCE;
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    protected String mappingAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String mappingAttribute(final String name) {
        return String.format(getLoggingLocale(), mappingAttribute$str(), name);
    }
    protected String analysisDefinitionParameter$str() {
        return "parameter '%1$s'";
    }
    @Override
    public final String analysisDefinitionParameter(final String name) {
        return String.format(getLoggingLocale(), analysisDefinitionParameter$str(), name);
    }
    protected String aliasDefinition$str() {
        return "alias '%1$s'";
    }
    @Override
    public final String aliasDefinition(final String name) {
        return String.format(getLoggingLocale(), aliasDefinition$str(), name);
    }
    protected String analysisDefinitionAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String analysisDefinitionAttribute(final String name) {
        return String.format(getLoggingLocale(), analysisDefinitionAttribute$str(), name);
    }
    protected String fieldTemplateAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String fieldTemplateAttribute(final String name) {
        return String.format(getLoggingLocale(), fieldTemplateAttribute$str(), name);
    }
    protected String customIndexSettingAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String customIndexSettingAttribute(final String name) {
        return String.format(getLoggingLocale(), customIndexSettingAttribute$str(), name);
    }
    protected String customIndexMappingAttribute$str() {
        return "attribute '%1$s'";
    }
    @Override
    public final String customIndexMappingAttribute(final String name) {
        return String.format(getLoggingLocale(), customIndexMappingAttribute$str(), name);
    }
}
